Option Explicit On 
Option Strict On
Option Compare Binary

Imports System

' <remarks>
'   Stellt Informationen fr das Ereignis, das 
'   beim Abschliessen der Enumeration relevant sind,
'   bereit.
' </remarks>
Public Class EnumerationFinishedEventArgs
    Inherits EventArgs

    Private m_blnCancelled As Boolean
    Private m_intValidFontsCount As Integer
    Private m_intInvalidFontsCount As Integer

    ' <summary>
    '   Erstellt eine neue Instanz der Klasse und 
    '   weist ihren Eigenschaften die bergebenen Werte zu.
    ' </summary>
    ' <param name="blnCancelled">Erfolte ein vorzeitiger 
    '   Abbruch des Enumerationsvorgangs?</param>
    ' <param name="intValidFontsCount">Anzahl der erfolgreich 
    '   geladenen Fonts.</param>
    ' <param name="intInvalidFontsCount">Anzahl der nicht 
    '   erfolgreich geladenen Fonts.</param>
    Public Sub New( _
      ByVal blnCancelled As Boolean, _
      ByVal intValidFontsCount As Integer, _
      ByVal intInvalidFontsCount As Integer)
        m_blnCancelled = blnCancelled
        m_intValidFontsCount = intValidFontsCount
        m_intInvalidFontsCount = intInvalidFontsCount
    End Sub

    ' <summary>
    '   Gibt an oder zurck, ob der Enumerationsvorgang 
    '   vorzeitig abgebrochen wurde.
    ' </summary>
    ' <value>Erfolgte ein vorzeitiger Abbruch 
    '   des Enumerationsvorgangs?</value>
    Public Property Cancelled() As Boolean
        Get
            Return m_blnCancelled
        End Get
        Set(ByVal Value As Boolean)
            m_blnCancelled = Value
        End Set
    End Property

    ' <summary>
    '   Gibt an oder gibt zurck, wie viele 
    '   Fonts erfolgreich geladen werden konnten.
    ' </summary>
    ' <value>Anzahl der erfolgreich geladenen Fonts.</value>
    Public Property ValidFontsCount() As Integer
        Get
            Return m_intValidFontsCount
        End Get
        Set(ByVal Value As Integer)
            m_intValidFontsCount = Value
        End Set
    End Property

    ' <summary>
    '   Gibt an oder gibt zurck, wie viele Fonts 
    '   nicht erfolgreich geladen werden konnten.
    ' </summary>
    ' <value>Anzahl der nicht erfolgreich geladenen Fonts.</value>
    Public Property InvalidFontsCount() As Integer
        Get
            Return m_intInvalidFontsCount
        End Get
        Set(ByVal Value As Integer)
            m_intInvalidFontsCount = Value
        End Set
    End Property
End Class